
void _ector_renderer_surface_set(Eo *obj, Ector_Renderer_Data *pd, Ector_Surface *s);

ECTOR_API ECTOR_API_WEAK EFL_VOID_FUNC_BODYV(ector_renderer_surface_set, EFL_FUNC_CALL(s), Ector_Surface *s);

Ector_Surface *_ector_renderer_surface_get(const Eo *obj, Ector_Renderer_Data *pd);

ECTOR_API ECTOR_API_WEAK EFL_FUNC_BODY_CONST(ector_renderer_surface_get, Ector_Surface *, NULL);

void _ector_renderer_transformation_set(Eo *obj, Ector_Renderer_Data *pd, const Eina_Matrix3 *m);

ECTOR_API ECTOR_API_WEAK EFL_VOID_FUNC_BODYV(ector_renderer_transformation_set, EFL_FUNC_CALL(m), const Eina_Matrix3 *m);

const Eina_Matrix3 *_ector_renderer_transformation_get(const Eo *obj, Ector_Renderer_Data *pd);

ECTOR_API ECTOR_API_WEAK EFL_FUNC_BODY_CONST(ector_renderer_transformation_get, const Eina_Matrix3 *, NULL);

void _ector_renderer_origin_set(Eo *obj, Ector_Renderer_Data *pd, double x, double y);

ECTOR_API ECTOR_API_WEAK EFL_VOID_FUNC_BODYV(ector_renderer_origin_set, EFL_FUNC_CALL(x, y), double x, double y);

void _ector_renderer_origin_get(const Eo *obj, Ector_Renderer_Data *pd, double *x, double *y);

ECTOR_API ECTOR_API_WEAK EFL_VOID_FUNC_BODYV_CONST(ector_renderer_origin_get, EFL_FUNC_CALL(x, y), double *x, double *y);

void _ector_renderer_visibility_set(Eo *obj, Ector_Renderer_Data *pd, Eina_Bool v);


static Eina_Error
__eolian_ector_renderer_visibility_set_reflect(Eo *obj, Eina_Value val)
{
   Eina_Error r = 0;   Eina_Bool cval;
   if (!eina_value_bool_convert(&val, &cval))
      {
         r = EINA_ERROR_VALUE_FAILED;
         goto end;
      }
   ector_renderer_visibility_set(obj, cval);
 end:
   eina_value_flush(&val);
   return r;
}

ECTOR_API ECTOR_API_WEAK EFL_VOID_FUNC_BODYV(ector_renderer_visibility_set, EFL_FUNC_CALL(v), Eina_Bool v);

Eina_Bool _ector_renderer_visibility_get(const Eo *obj, Ector_Renderer_Data *pd);


static Eina_Value
__eolian_ector_renderer_visibility_get_reflect(const Eo *obj)
{
   Eina_Bool val = ector_renderer_visibility_get(obj);
   return eina_value_bool_init(val);
}

ECTOR_API ECTOR_API_WEAK EFL_FUNC_BODY_CONST(ector_renderer_visibility_get, Eina_Bool, 0);

void _ector_renderer_color_set(Eo *obj, Ector_Renderer_Data *pd, int r, int g, int b, int a);

ECTOR_API ECTOR_API_WEAK EFL_VOID_FUNC_BODYV(ector_renderer_color_set, EFL_FUNC_CALL(r, g, b, a), int r, int g, int b, int a);

void _ector_renderer_color_get(const Eo *obj, Ector_Renderer_Data *pd, int *r, int *g, int *b, int *a);

ECTOR_API ECTOR_API_WEAK EFL_VOID_FUNC_BODYV_CONST(ector_renderer_color_get, EFL_FUNC_CALL(r, g, b, a), int *r, int *g, int *b, int *a);

unsigned int _ector_renderer_crc_get(const Eo *obj, Ector_Renderer_Data *pd);

ECTOR_API ECTOR_API_WEAK EFL_FUNC_BODY_CONST(ector_renderer_crc_get, unsigned int, 0);

void _ector_renderer_comp_method_set(Eo *obj, Ector_Renderer_Data *pd, Ector_Buffer *comp, Efl_Gfx_Vg_Composite_Method method);

ECTOR_API ECTOR_API_WEAK EFL_VOID_FUNC_BODYV(ector_renderer_comp_method_set, EFL_FUNC_CALL(comp, method), Ector_Buffer *comp, Efl_Gfx_Vg_Composite_Method method);
ECTOR_API ECTOR_API_WEAK EFL_FUNC_BODYV(ector_renderer_draw, Eina_Bool, 0, EFL_FUNC_CALL(op, clips, mul_col), Efl_Gfx_Render_Op op, Eina_Array *clips, unsigned int mul_col);
ECTOR_API ECTOR_API_WEAK EFL_FUNC_BODY(ector_renderer_prepare, Eina_Bool, 0);

void _ector_renderer_efl_object_destructor(Eo *obj, Ector_Renderer_Data *pd);


Efl_Object *_ector_renderer_efl_object_finalize(Eo *obj, Ector_Renderer_Data *pd);


static Eina_Bool
_ector_renderer_class_initializer(Efl_Class *klass)
{
   const Efl_Object_Ops *opsp = NULL;

   const Efl_Object_Property_Reflection_Ops *ropsp = NULL;

#ifndef ECTOR_RENDERER_EXTRA_OPS
#define ECTOR_RENDERER_EXTRA_OPS
#endif

   EFL_OPS_DEFINE(ops,
      EFL_OBJECT_OP_FUNC(ector_renderer_surface_set, _ector_renderer_surface_set),
      EFL_OBJECT_OP_FUNC(ector_renderer_surface_get, _ector_renderer_surface_get),
      EFL_OBJECT_OP_FUNC(ector_renderer_transformation_set, _ector_renderer_transformation_set),
      EFL_OBJECT_OP_FUNC(ector_renderer_transformation_get, _ector_renderer_transformation_get),
      EFL_OBJECT_OP_FUNC(ector_renderer_origin_set, _ector_renderer_origin_set),
      EFL_OBJECT_OP_FUNC(ector_renderer_origin_get, _ector_renderer_origin_get),
      EFL_OBJECT_OP_FUNC(ector_renderer_visibility_set, _ector_renderer_visibility_set),
      EFL_OBJECT_OP_FUNC(ector_renderer_visibility_get, _ector_renderer_visibility_get),
      EFL_OBJECT_OP_FUNC(ector_renderer_color_set, _ector_renderer_color_set),
      EFL_OBJECT_OP_FUNC(ector_renderer_color_get, _ector_renderer_color_get),
      EFL_OBJECT_OP_FUNC(ector_renderer_crc_get, _ector_renderer_crc_get),
      EFL_OBJECT_OP_FUNC(ector_renderer_comp_method_set, _ector_renderer_comp_method_set),
      EFL_OBJECT_OP_FUNC(ector_renderer_draw, NULL),
      EFL_OBJECT_OP_FUNC(ector_renderer_prepare, NULL),
      EFL_OBJECT_OP_FUNC(efl_destructor, _ector_renderer_efl_object_destructor),
      EFL_OBJECT_OP_FUNC(efl_finalize, _ector_renderer_efl_object_finalize),
      ECTOR_RENDERER_EXTRA_OPS
   );
   opsp = &ops;

   static const Efl_Object_Property_Reflection refl_table[] = {
      {"visibility", __eolian_ector_renderer_visibility_set_reflect, __eolian_ector_renderer_visibility_get_reflect},
   };
   static const Efl_Object_Property_Reflection_Ops rops = {
      refl_table, EINA_C_ARRAY_LENGTH(refl_table)
   };
   ropsp = &rops;

   return efl_class_functions_set(klass, opsp, ropsp);
}

static const Efl_Class_Description _ector_renderer_class_desc = {
   EO_VERSION,
   "Ector.Renderer",
   EFL_CLASS_TYPE_REGULAR_NO_INSTANT,
   sizeof(Ector_Renderer_Data),
   _ector_renderer_class_initializer,
   NULL,
   NULL
};

EFL_DEFINE_CLASS(ector_renderer_class_get, &_ector_renderer_class_desc, EFL_OBJECT_CLASS, NULL);
